]> granicus.if.org Git - neomutt/commitdiff
rename mailbox functions
authorRichard Russon <rich@flatcap.org>
Wed, 15 May 2019 23:31:46 +0000 (00:31 +0100)
committerRichard Russon <rich@flatcap.org>
Thu, 16 May 2019 12:56:09 +0000 (13:56 +0100)
Fix mailbox function naming for consistency

commands.c
enter.c
index.c
mailbox.c
mailbox.h
main.c
mbox/mbox.c
monitor.c
mx.c

index b8149d7fb76eaa2a12a44a45457a1d23c5f603cc..01058a647fcc32e0f4a2012159c15a7cf7eef666 100644 (file)
@@ -1086,7 +1086,7 @@ int mutt_save_message(struct Mailbox *m, struct EmailList *el, bool delete,
   struct Mailbox *m_comp = NULL;
   if (ctx_save->mailbox->compress_info)
   {
-    m_comp = mutt_find_mailbox(ctx_save->mailbox->realpath);
+    m_comp = mutt_mailbox_find(ctx_save->mailbox->realpath);
   }
   /* We probably haven't been opened yet */
   if (m_comp && (m_comp->msg_count == 0))
diff --git a/enter.c b/enter.c
index 276d50547a240dfc04bd80cc9659de72d4a1a923..d7ad1ad74c570926372fbd34ae67b907061f011e 100644 (file)
--- a/enter.c
+++ b/enter.c
@@ -502,7 +502,7 @@ int mutt_enter_string_full(char *buf, size_t buflen, int col,
           {
             first = true; /* clear input if user types a real key later */
             mutt_mb_wcstombs(buf, buflen, state->wbuf, state->curpos);
-            mutt_mailbox(Context ? Context->mailbox : NULL, buf, buflen);
+            mutt_mailbox_next(Context ? Context->mailbox : NULL, buf, buflen);
             state->curpos = state->lastchar =
                 mutt_mb_mbstowcs(&state->wbuf, &state->wbuflen, 0, buf);
             break;
diff --git a/index.c b/index.c
index 71a127747cb378b85e5598a4f827a20a0a3771d8..d87f1e11d5cd5ac5cd5743cc09e576ec015d91be 100644 (file)
--- a/index.c
+++ b/index.c
@@ -623,7 +623,7 @@ static int main_change_folder(struct Menu *menu, int op, struct Mailbox *m,
   {
     // Try to see if the buffer matches a description before we bail.
     // We'll receive a non-null pointer if there is a corresponding mailbox.
-    m = mutt_find_mailbox_desc(buf);
+    m = mutt_mailbox_find_desc(buf);
     if (m)
     {
       magic = m->magic;
@@ -2227,7 +2227,7 @@ int mutt_index_menu(void)
         {
           mutt_buffer_strcpy(folderbuf, mutt_b2s(Context->mailbox->pathbuf));
           mutt_buffer_pretty_mailbox(folderbuf);
-          mutt_buffer_mailbox(Context ? Context->mailbox : NULL, folderbuf);
+          mutt_mailbox_next_buffer(Context ? Context->mailbox : NULL, folderbuf);
           if (mutt_buffer_is_empty(folderbuf))
           {
             mutt_error(_("No mailboxes have new mail"));
@@ -2273,7 +2273,7 @@ int mutt_index_menu(void)
           {
             /* By default, fill buf with the next mailbox that contains unread
              * mail */
-            mutt_buffer_mailbox(Context ? Context->mailbox : NULL, folderbuf);
+            mutt_mailbox_next_buffer(Context ? Context->mailbox : NULL, folderbuf);
           }
 
           if (mutt_buffer_enter_fname(cp, folderbuf, true) == -1)
index 45da86e81f0f59dff778e1e3380fa856f969f2a8..fff3864b02019c85a7688fbc3361b40f7a289788 100644 (file)
--- a/mailbox.h
+++ b/mailbox.h
@@ -77,6 +77,10 @@ typedef uint16_t AclFlags;          ///< Flags, e.g. #MUTT_ACL_ADMIN
 
 #define MUTT_ACL_ALL    ((1 << 11) - 1)
 
+/* force flags passed to mutt_mailbox_check() */
+#define MUTT_MAILBOX_CHECK_FORCE       (1 << 0)
+#define MUTT_MAILBOX_CHECK_FORCE_STATS (1 << 1)
+
 /**
  * struct Mailbox - A mailbox
  */
@@ -152,30 +156,20 @@ STAILQ_HEAD(MailboxList, MailboxNode);
 
 extern struct MailboxList AllMailboxes; ///< List of all Mailboxes
 
-struct Mailbox *mailbox_new(void);
-void            mailbox_free(struct Mailbox **ptr);
-
-struct Mailbox *mutt_find_mailbox(const char *path);
-struct Mailbox *mutt_find_mailbox_desc(const char *desc);
-void mutt_update_mailbox(struct Mailbox *m);
-
-void mutt_mailbox_cleanup(const char *path, struct stat *st);
-
-/** mark mailbox just left as already notified */
-void mutt_mailbox_setnotified(struct Mailbox *m);
-
-/* force flags passed to mutt_mailbox_check() */
-#define MUTT_MAILBOX_CHECK_FORCE       (1 << 0)
-#define MUTT_MAILBOX_CHECK_FORCE_STATS (1 << 1)
-
-void mutt_buffer_mailbox(struct Mailbox *m_cur, struct Buffer *s);
-void mutt_mailbox(struct Mailbox *m_cur, char *s, size_t slen);
-bool mutt_mailbox_list(void);
-int mutt_mailbox_check(struct Mailbox *m_cur, int force);
-bool mutt_mailbox_notify(struct Mailbox *m_cur);
-void mutt_mailbox_changed(struct Mailbox *m, enum MailboxNotification action);
-
-void mutt_mailbox_size_add(struct Mailbox *m, const struct Email *e);
-void mutt_mailbox_size_sub(struct Mailbox *m, const struct Email *e);
+void            mailbox_free             (struct Mailbox **ptr);
+struct Mailbox *mailbox_new              (void);
+void            mutt_mailbox_changed     (struct Mailbox *m, enum MailboxNotification action);
+int             mutt_mailbox_check       (struct Mailbox *m_cur, int force);
+void            mutt_mailbox_cleanup     (const char *path, struct stat *st);
+struct Mailbox *mutt_mailbox_find        (const char *path);
+struct Mailbox *mutt_mailbox_find_desc   (const char *desc);
+bool            mutt_mailbox_list        (void);
+void            mutt_mailbox_next_buffer (struct Mailbox *m_cur, struct Buffer *s);
+void            mutt_mailbox_next        (struct Mailbox *m_cur, char *s, size_t slen);
+bool            mutt_mailbox_notify      (struct Mailbox *m_cur);
+void            mutt_mailbox_set_notified(struct Mailbox *m);
+void            mutt_mailbox_size_add    (struct Mailbox *m, const struct Email *e);
+void            mutt_mailbox_size_sub    (struct Mailbox *m, const struct Email *e);
+void            mutt_mailbox_update      (struct Mailbox *m);
 
 #endif /* MUTT_MAILBOX_H */
diff --git a/main.c b/main.c
index 64244ca7c375ec4fbbec268591308cedabd96b47..1401c86851fb340faa1c3208b424e2e36ef4081e 100644 (file)
--- a/main.c
+++ b/main.c
@@ -1135,7 +1135,7 @@ int main(int argc, char *argv[], char *envp[])
         goto main_curses; // TEST37: neomutt -Z (no new mail)
       }
       mutt_buffer_reset(folder);
-      mutt_buffer_mailbox(Context ? Context->mailbox : NULL, folder);
+      mutt_mailbox_next_buffer(Context ? Context->mailbox : NULL, folder);
 #ifdef USE_IMAP
       C_ImapPassive = passive;
 #endif
@@ -1170,7 +1170,7 @@ int main(int argc, char *argv[], char *envp[])
       if (C_Spoolfile)
       {
         // Check if C_Spoolfile corresponds a mailboxes' description.
-        struct Mailbox *desc_m = mutt_find_mailbox_desc(C_Spoolfile);
+        struct Mailbox *desc_m = mutt_mailbox_find_desc(C_Spoolfile);
         if (desc_m)
           mutt_buffer_strcpy(folder, desc_m->realpath);
         else
index 95f661aa5b394132c485cfc26bd1ff7896757e4d..6627289f70efb2b19132e0717a7b86707bfd5564 100644 (file)
@@ -1424,9 +1424,9 @@ static int mbox_mbox_sync(struct Mailbox *m, int *index_hint)
 
   if (C_CheckMboxSize)
   {
-    struct Mailbox *tmp = mutt_find_mailbox(mutt_b2s(m->pathbuf));
+    struct Mailbox *tmp = mutt_mailbox_find(mutt_b2s(m->pathbuf));
     if (tmp && !tmp->has_new)
-      mutt_update_mailbox(tmp);
+      mutt_mailbox_update(tmp);
   }
 
   return 0; /* signal success */
index fbb68335f6fbcbb0a14f5183f7e8436eed3ea589..05bb07d90785ef73e6074f586be39723d4aeab9a 100644 (file)
--- a/monitor.c
+++ b/monitor.c
@@ -536,7 +536,7 @@ int mutt_monitor_remove(struct Mailbox *m)
     }
     else
     {
-      if (mutt_find_mailbox(Context->mailbox->realpath))
+      if (mutt_mailbox_find(Context->mailbox->realpath))
       {
         rc = 1;
         goto cleanup;
diff --git a/mx.c b/mx.c
index b0ac47e7429f3f1d43e7eaef6da0a4b6dba9df2b..460d069b6b759f040b57cce4b91cb85d9abe09d4 100644 (file)
--- a/mx.c
+++ b/mx.c
@@ -388,7 +388,7 @@ void mx_fastclose_mailbox(struct Mailbox *m)
   /* never announce that a mailbox we've just left has new mail. #3290
    * TODO: really belongs in mx_mbox_close, but this is a nice hook point */
   if (!m->peekonly)
-    mutt_mailbox_setnotified(m);
+    mutt_mailbox_set_notified(m);
 
   if (m->mx_ops)
     m->mx_ops->mbox_close(m);
--- a/mailbox.c
+++ b/mailbox.c
@@ -223,9 +223,9 @@ void mutt_mailbox_cleanup(const char *path, struct stat *st)
 
   if (C_CheckMboxSize)
   {
-    struct Mailbox *m = mutt_find_mailbox(path);
+    struct Mailbox *m = mutt_mailbox_find(path);
     if (m && !m->has_new)
-      mutt_update_mailbox(m);
+      mutt_mailbox_update(m);
   }
   else
   {
@@ -260,11 +260,11 @@ void mutt_mailbox_cleanup(const char *path, struct stat *st)
 }
 
 /**
* mutt_find_mailbox - Find the mailbox with a given path
  * @param path Path to match
  * @retval ptr Matching Mailbox
  */
-struct Mailbox *mutt_find_mailbox(const char *path)
+struct Mailbox *mutt_mailbox_find(const char *path)
 {
   if (!path)
     return NULL;
@@ -289,12 +289,12 @@ struct Mailbox *mutt_find_mailbox(const char *path)
 }
 
 /**
* mutt_find_mailbox_desc - Find the mailbox with a given description
  * @param desc Description to match
  * @retval ptr Matching Mailbox
  * @retval NULL No matching mailbox found
  */
-struct Mailbox *mutt_find_mailbox_desc(const char *desc)
+struct Mailbox *mutt_mailbox_find_desc(const char *desc)
 {
   if (!desc)
     return NULL;
@@ -310,10 +310,10 @@ struct Mailbox *mutt_find_mailbox_desc(const char *desc)
 }
 
 /**
* mutt_update_mailbox - Get the mailbox's current size
  * @param m Mailbox to check
  */
-void mutt_update_mailbox(struct Mailbox *m)
+void mutt_mailbox_update(struct Mailbox *m)
 {
   struct stat sb;
 
@@ -461,10 +461,10 @@ bool mutt_mailbox_list(void)
 }
 
 /**
* mutt_mailbox_setnotified - Note when the user was last notified of new mail
  * @param m Mailbox
  */
-void mutt_mailbox_setnotified(struct Mailbox *m)
+void mutt_mailbox_set_notified(struct Mailbox *m)
 {
   if (!m)
     return;
@@ -493,13 +493,13 @@ bool mutt_mailbox_notify(struct Mailbox *m_cur)
 }
 
 /**
* mutt_buffer_mailbox - incoming folders completion routine
  * @param m_cur Current Mailbox
  * @param s     Buffer containing name of current mailbox
  *
  * Given a folder name, find the next incoming folder with new mail.
  */
-void mutt_buffer_mailbox(struct Mailbox *m_cur, struct Buffer *s)
+void mutt_mailbox_next_buffer(struct Mailbox *m_cur, struct Buffer *s)
 {
   mutt_buffer_expand_path(s);
 
@@ -514,7 +514,7 @@ void mutt_buffer_mailbox(struct Mailbox *m_cur, struct Buffer *s)
         if (np->mailbox->magic == MUTT_NOTMUCH) /* only match real mailboxes */
           continue;
         mutt_buffer_expand_path(np->mailbox->pathbuf);
-        if ((found || pass) && np->mailbox->has_new)
+        if ((found || (pass > 0)) && np->mailbox->has_new)
         {
           mutt_buffer_strcpy(s, mutt_b2s(np->mailbox->pathbuf));
           mutt_buffer_pretty_mailbox(s);
@@ -533,19 +533,19 @@ void mutt_buffer_mailbox(struct Mailbox *m_cur, struct Buffer *s)
 }
 
 /**
* mutt_mailbox - incoming folders completion routine
  * @param m_cur Current Mailbox
  * @param s     Buffer containing name of current mailbox
  * @param slen  Buffer length
  *
  * Given a folder name, find the next incoming folder with new mail.
  */
-void mutt_mailbox(struct Mailbox *m_cur, char *s, size_t slen)
+void mutt_mailbox_next(struct Mailbox *m_cur, char *s, size_t slen)
 {
   struct Buffer *s_buf = mutt_buffer_pool_get();
 
   mutt_buffer_addstr(s_buf, NONULL(s));
-  mutt_buffer_mailbox(m_cur, s_buf);
+  mutt_mailbox_next_buffer(m_cur, s_buf);
   mutt_str_strfcpy(s, mutt_b2s(s_buf), slen);
 
   mutt_buffer_pool_release(&s_buf);
@@ -260,11 +260,11 @@ void mutt_mailbox_cleanup(const char *path, struct stat *st)
 
 /**
- * mutt_find_mailbox - Find the mailbox with a given path
+ * mutt_mailbox_find - Find the mailbox with a given path
  * @param path Path to match
  * @retval ptr Matching Mailbox
@@ -289,12 +289,12 @@ struct Mailbox *mutt_find_mailbox(const char *path)
 
 /**
- * mutt_find_mailbox_desc - Find the mailbox with a given description
+ * mutt_mailbox_find_desc - Find the mailbox with a given description
  * @param desc Description to match
  * @retval ptr Matching Mailbox
@@ -310,10 +310,10 @@ struct Mailbox *mutt_find_mailbox_desc(const char *desc)
 
 /**
- * mutt_update_mailbox - Get the mailbox's current size
+ * mutt_mailbox_update - Get the mailbox's current size
  * @param m Mailbox to check
  */
@@ -461,10 +461,10 @@ bool mutt_mailbox_list(void)
 
 /**
- * mutt_mailbox_setnotified - Note when the user was last notified of new mail
+ * mutt_mailbox_set_notified - Note when the user was last notified of new mail
  * @param m Mailbox
  */
@@ -493,13 +493,13 @@ bool mutt_mailbox_notify(struct Mailbox *m_cur)
 
 /**
- * mutt_buffer_mailbox - incoming folders completion routine
+ * mutt_mailbox_next_buffer - incoming folders completion routine
  * @param m_cur Current Mailbox
  * @param s     Buffer containing name of current mailbox
@@ -533,19 +533,19 @@ void mutt_buffer_mailbox(struct Mailbox *m_cur, struct Buffer *s)
 
 /**
- * mutt_mailbox - incoming folders completion routine
+ * mutt_mailbox_next - incoming folders completion routine
  * @param m_cur Current Mailbox
  * @param s     Buffer containing name of current mailbox
index 88b806febdf3607bd3ce0cb69b428a1fadc1d1f0..5480020f247b5f6540a5ff82d4cf6e920e3b6741 100644 (file)